@@ -2,17 +2,19 @@ from .models.user import User as user
 from .models.reply import Reply as reply
 from .models.post import Post as post
 from .models.blog import Blog as blog
+from .sockets import Sockets as socket, Events
 
 class Bubblez:
     stand_header = {"Content-Type": "application/x-www-form-urlencoded"}
 
-    def __init__(self, username, token) -> None:
-        self.user = self.User(username, token)
-        self.post = self.Post(token)
-        self.reply = self.Reply(token, username)
-        self.blog = self.Blog(username, token)
+    def __init__(self, username, token, verbose=False) -> None:
+        self.user = self.User(self)
+        self.post = self.Post(self)
+        self.reply = self.Reply(self)
+        self.blog = self.Blog(self)
         self.token = token 
-        self.username = username 
+        self.username = username
+        self.verbose = verbose
 
     class User(user):
         pass 
@@ -24,4 +26,9 @@ class Bubblez:
         pass 
 
     class Blog(blog):
-        pass 
\ No newline at end of file
+        pass 
+
+class Sockets(socket):
+    class Events(Events):
+        pass 
+    pass
\ No newline at end of file
